@@ -40,7 +40,7 @@ BOOL cmd_plusplus(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             runinfo->mRCode = 0;
         }
         else {
-            err_msg("not found variable", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("not found variable", runinfo->mSName, runinfo->mSLine);
             return FALSE;
         }
     }
@@ -64,7 +64,7 @@ BOOL cmd_minusminus(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             runinfo->mRCode = 0;
         }
         else {
-            err_msg("not found variable", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("not found variable", runinfo->mSName, runinfo->mSLine);
             return FALSE;
         }
     }
@@ -85,7 +85,7 @@ BOOL cmd_plus(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, 128, "%d\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -114,7 +114,7 @@ BOOL cmd_minus(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, 128, "%d\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -143,7 +143,7 @@ BOOL cmd_mult(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, 128, "%d\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -169,7 +169,7 @@ BOOL cmd_div(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int num2 = atoi(runinfo->mArgsRuntime[1]);
 
         if(num2 == 0) {
-            err_msg("zero div", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("zero div", runinfo->mSName, runinfo->mSLine);
             return FALSE;
         }
 
@@ -179,7 +179,7 @@ BOOL cmd_div(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, 128, "%d\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -208,7 +208,7 @@ BOOL cmd_mod(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, 128, "%d\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -237,7 +237,7 @@ BOOL cmd_pow(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, 128, "%d\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
@@ -264,7 +264,7 @@ BOOL cmd_abs(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
         int size = snprintf(buf, 128, "%d\n", num);
 
         if(!fd_write(nextout, buf, size)) {
-            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine, runinfo->mArgs[0]);
+            err_msg("signal interrupt", runinfo->mSName, runinfo->mSLine);
             runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
             return FALSE;
         }
