@@ -116,7 +116,7 @@ static BOOL expand_parametor(sStrings* strings, char* str, sCommand* command, sO
                             FREE(buf.mBuf);
                             char buf[128];
                             snprintf(buf, 128, "no such as object(%s)", env->mName);
-                            err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            err_msg(buf, runinfo->mSName, runinfo->mSLine);
                             return FALSE;
                         }
                     }
@@ -207,7 +207,7 @@ static BOOL expand_parametor(sStrings* strings, char* str, sCommand* command, sO
                             if(*key == 0) {
                                 char buf2[128];
                                 snprintf(buf2, 128, "need hash key(%s)", env->mName);
-                                err_msg(buf2, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                                err_msg(buf2, runinfo->mSName, runinfo->mSLine);
                                 FREE(key);
                                 FREE(buf.mBuf);
                                 return FALSE;
@@ -223,7 +223,7 @@ static BOOL expand_parametor(sStrings* strings, char* str, sCommand* command, sO
                         default: {
                             char buf2[128];
                             snprintf(buf2, 128, "can't expand variable because of type(%s)", env->mName);
-                            err_msg(buf2, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            err_msg(buf2, runinfo->mSName, runinfo->mSLine);
                             FREE(key);
                             FREE(buf.mBuf);
                             return FALSE;
@@ -240,7 +240,7 @@ static BOOL expand_parametor(sStrings* strings, char* str, sCommand* command, sO
 
                 if(!run(env->mBlock, nextin, nextout2, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject))
                 {
-                    err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    err_msg_adding("run time error", runinfo->mSName, runinfo->mSLine);
                     runinfo->mRCode = rcode;
                     FREE(buf.mBuf);
                     return FALSE;
@@ -300,7 +300,7 @@ static BOOL expand_glob(sStrings* strings, char* str, sCommand* command, sObject
     int rc = glob(str, 0, NULL, &result);
 
     if(rc == GLOB_NOSPACE) {
-        err_msg("expand_glob: out of space during glob operation", runinfo->mSName, runinfo->mSLine, str);
+        err_msg("expand_glob: out of space during glob operation", runinfo->mSName, runinfo->mSLine);
         globfree(&result);
         return FALSE;
     }
@@ -389,7 +389,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                         if(j + 1 >= strings->mNumber) {
                             char buf[BUFSIZ];
                             snprintf(buf, BUFSIZ, "invalid option with argument(%s)", arg);
-                            err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            err_msg(buf, runinfo->mSName, runinfo->mSLine);
                             sString_delete(strings);
                             return FALSE;
                         }
@@ -400,7 +400,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                         {
                             char buf[BUFSIZ];
                             snprintf(buf, BUFSIZ, "option number max (%s)\n", arg);
-                            err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            err_msg(buf, runinfo->mSName, runinfo->mSLine);
                             sString_delete(strings);
                             return FALSE;
                         }
@@ -418,7 +418,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                             if(!sRunInfo_put_option(runinfo, MANAGED arg)) {
                                 char buf[BUFSIZ];
                                 snprintf(buf, BUFSIZ, "option number max (%s)\n", arg);
-                                err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                                err_msg(buf, runinfo->mSName, runinfo->mSLine);
                                 sString_delete(strings);
                                 return FALSE;
                             }
@@ -452,7 +452,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
             /*
             option with glob is error on the parser
             if(command->mArgsFlags[i] & XYZSH_ARGUMENT_GLOB) { 
-                err_msg("invalid option", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                err_msg("invalid option", runinfo->mSName, runinfo->mSLine);
                 return FALSE;
             }
             else {
@@ -468,7 +468,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                     if(i + 1 >= command->mArgsNum) {
                         char buf[BUFSIZ];
                         snprintf(buf, BUFSIZ, "invalid option with argument(%s)", arg);
-                        err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        err_msg(buf, runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
 
@@ -476,7 +476,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                     if(command->mArgsFlags[i+1] & XYZSH_ARGUMENT_GLOB || command->mArgsFlags[i+1] & XYZSH_ARGUMENT_OPTION) {
                         char buf[BUFSIZ];
                         snprintf(buf, BUFSIZ, "invalid option with argument(%s)", arg);
-                        err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        err_msg(buf, runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
 
@@ -490,7 +490,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                         if(strings->mNumber == 0) {
                             char buf[BUFSIZ];
                             snprintf(buf, BUFSIZ, "invalid option with argument(%s)", arg);
-                            err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            err_msg(buf, runinfo->mSName, runinfo->mSLine);
                             sString_delete(strings);
                             return FALSE;
                         }
@@ -500,7 +500,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                         {
                             char buf[BUFSIZ];
                             snprintf(buf, BUFSIZ, "option number max (%s)\n", arg);
-                            err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            err_msg(buf, runinfo->mSName, runinfo->mSLine);
                             sString_delete(strings);
                             return FALSE;
                         }
@@ -514,7 +514,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                         {
                             char buf[BUFSIZ];
                             snprintf(buf, BUFSIZ, "option number max (%s)\n", arg);
-                            err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            err_msg(buf, runinfo->mSName, runinfo->mSLine);
                             return FALSE;
                         }
                     }
@@ -524,7 +524,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                     if(!sRunInfo_put_option(runinfo, MANAGED STRDUP(arg))) {
                         char buf[BUFSIZ];
                         snprintf(buf, BUFSIZ, "option number max (%s)\n", arg);
-                        err_msg(buf, runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        err_msg(buf, runinfo->mSName, runinfo->mSLine);
                         return FALSE;
                     }
                 }
@@ -578,7 +578,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                     }
 
                     if(strings->mNumber == 0) {
-                        err_msg("require file name by this redirect", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        err_msg("require file name by this redirect", runinfo->mSName, runinfo->mSLine);
                         sString_delete(strings);
                         return FALSE;
                     }
@@ -593,7 +593,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                     }
 
                     if(strings2->mNumber == 0) {
-                        err_msg("require file name by this redirect", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        err_msg("require file name by this redirect", runinfo->mSName, runinfo->mSLine);
                         sString_delete(strings);
                         sString_delete(strings2);
                         return FALSE;
@@ -614,7 +614,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                     }
 
                     if(strings->mNumber == 0) {
-                        err_msg("require file name by this redirect", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                        err_msg("require file name by this redirect", runinfo->mSName, runinfo->mSLine);
                         sString_delete(strings);
                         return FALSE;
                     }
@@ -637,7 +637,7 @@ BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sR
                 }
 
                 if(strings->mNumber == 0) {
-                    err_msg("require file name by this redirect", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                    err_msg("require file name by this redirect", runinfo->mSName, runinfo->mSLine);
                     sString_delete(strings);
                     return FALSE;
                 }
