@@ -324,67 +324,6 @@ struct sTEmulatorFunArg {
 
 static void temulator_fun(void* arg)
 {
-/*
-puts("AAA");
-puts("BBB");
-char buf[128];
-scanf("%s", buf);
-
-printf("(%s)\n", buf);
-
-int n;
-scanf("%d", &n);
-
-    struct sTEmulatorFunArg* targ = arg;
-
-    stack_start_stack();
-    int rcode = 0;
-    sObject* block = BLOCK_NEW_STACK();
-    int sline = 1;
-    if(parse("bash", "xyzsh", &sline, block, NULL)) {
-        xyzsh_set_signal();
-
-        sObject* fun = FUN_NEW_STACK(NULL);
-        sObject* stackframe = UOBJECT_NEW_GC(8, gXyzshObject, "_stackframe", FALSE);
-        vector_add(gStackFrames, stackframe);
-        //uobject_init(stackframe);
-        SFUN(fun).mLocalObjects = stackframe;
-
-        sObject* argv2 = VECTOR_NEW_GC(16, FALSE);
-        int i;
-        for(i=0; i<targ->argc; i++) {
-            vector_add(argv2, STRING_NEW_GC(targ->argv[i], FALSE));
-        }
-        uobject_put(SFUN(fun).mLocalObjects, "ARGV", argv2);
-
-        if(!run(block, gStdin, gStdout, &rcode, gCurrentObject, fun)) {
-            if(rcode == RCODE_BREAK) {
-                fprintf(stderr, "invalid break. Not in a loop\n");
-            }
-            else if(rcode & RCODE_RETURN) {
-                fprintf(stderr, "invalid return. Not in a function\n");
-            }
-            else if(rcode == RCODE_EXIT) {
-                stack_end_stack();
-            }
-            else {
-                fprintf(stderr, "run time error\n");
-                fprintf(stderr, "%s", string_c_str(gErrMsg));
-            }
-        }
-        (void)vector_pop_back(gStackFrames);
-    }
-    else {
-        fprintf(stderr, "parser error\n");
-        fprintf(stderr, "%s", string_c_str(gErrMsg));
-    }
-
-    if(rcode != 0) {
-        fprintf(stderr, "return code is %d\n", rcode);
-    }
-    stack_end_stack();
-*/
-
     struct sTEmulatorFunArg* targ = arg;
 
     /// start interactive shell ///
@@ -481,10 +420,10 @@ scanf("%d", &n);
     }
 }
 
-BOOL gSigChld = FALSE;
-BOOL gSigWinch = FALSE;
+static BOOL gSigChld = FALSE;
+static BOOL gSigWinch = FALSE;
 
-void handler(int signo)
+static void handler(int signo)
 {
     switch (signo) {
       case SIGCHLD:
@@ -518,6 +457,7 @@ static struct timeval timeval_add(struct timeval a, struct timeval b)
     return a;
 }
 
+
 void xyzsh_readline_interface_on_curses(char* cmdline, int cursor_point, char** argv, int argc, BOOL exit_in_spite_ofjob_exist, BOOL welcome_msg)
 {
     gSigChld = FALSE;
@@ -623,6 +563,7 @@ void xyzsh_readline_interface_on_curses(char* cmdline, int cursor_point, char**
     temulator_final(temulator);
 }
 
+
 void xyzsh_readline_interface(char* cmdline, int cursor_point, char** argv, int argc, BOOL exit_in_spite_ofjob_exist, BOOL welcome_msg)
 {
     /// start interactive shell ///
