@@ -25,7 +25,7 @@ BOOL load_file(char* fname, sObject* nextin, sObject* nextout, sRunInfo* runinfo
 {
     int fd = open(fname, O_RDONLY);
     if(fd < 0) {
-        err_msg("open error", runinfo->mSName, runinfo->mSLine, fname);
+        err_msg("open error", runinfo->mSName, runinfo->mSLine);
         return FALSE;
     }
 
@@ -34,7 +34,7 @@ BOOL load_file(char* fname, sObject* nextin, sObject* nextout, sRunInfo* runinfo
     int buf_size;
     if(!bufsiz_read(fd, ALLOC &buf, &buf_len, &buf_size)) {
         sCommand* command = runinfo->mCommand;
-        err_msg("signal interrupt16", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+        err_msg("signal interrupt16", runinfo->mSName, runinfo->mSLine);
         runinfo->mRCode = RCODE_SIGNAL_INTERRUPT;
         close(fd);
         return FALSE;
@@ -78,7 +78,7 @@ BOOL load_file(char* fname, sObject* nextin, sObject* nextout, sRunInfo* runinfo
     else {
         FREE(buf);
         sCommand* command = runinfo->mCommand;
-        err_msg_adding("parser error", runinfo->mSName, runinfo->mSLine, "parser");
+        err_msg_adding("parser error", runinfo->mSName, runinfo->mSLine);
         stack_end_stack();
         return FALSE;
     }
@@ -111,20 +111,20 @@ BOOL load_so_file(char* fname, sObject* nextin, sObject* nextout, sRunInfo* runi
     if(hash_item(gDynamicLibraryFinals, path) == NULL) {
         void* handle = dlopen(path, RTLD_LAZY);
         if(handle == NULL) {
-            err_msg((char*)dlerror(), runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg((char*)dlerror(), runinfo->mSName, runinfo->mSLine);
             return FALSE;
         }
 
         int (*init_func)() = dlsym(handle, "dl_init");
         int (*final_func)() = dlsym(handle, "dl_final");
         if(init_func == NULL || final_func == NULL) {
-            err_msg("not found dl_init or dl_final", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("not found dl_init or dl_final", runinfo->mSName, runinfo->mSLine);
             dlclose(handle);
             return FALSE;
         }
 
         if(init_func(NULL) != 0) {
-            err_msg("false in initialize the dynamic library", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("false in initialize the dynamic library", runinfo->mSName, runinfo->mSLine);
             dlclose(handle);
             return FALSE;
         }
@@ -147,7 +147,7 @@ BOOL load_so_file(char* fname, sObject* nextin, sObject* nextout, sRunInfo* runi
         }
 
         if(p == path) {
-            err_msg("can't load initilize xyzsh script", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+            err_msg("can't load initilize xyzsh script", runinfo->mSName, runinfo->mSLine);
             dlclose(handle);
             return FALSE;
         }
