@@ -93,7 +93,7 @@ static void xyzsh_read_rc_mini()
 
 void xyzsh_init(enum eAppType app_type, BOOL no_runtime_script)
 {
-    setenv("XYZSH_VERSION", "1.4.5", 1);
+    setenv("XYZSH_VERSION", "1.4.6", 1);
     setenv("XYZSH_DOCDIR", DOCDIR, 1);
     setenv("XYZSH_DATAROOTDIR", DOCDIR, 1);
     setenv("XYZSH_EXT_PATH", EXTDIR, 1);
@@ -191,23 +191,19 @@ void xyzsh_final()
     stack_final();
 }
 
-void err_msg(char* msg, char* sname, int line, char* command)
+void err_msg(char* msg, char* sname, int line)
 {
     char* tmp = MALLOC(strlen(sname) + 128 + strlen(msg));
-    if(command) {
-        snprintf(tmp, strlen(sname) + 128 + strlen(msg), "%s %d: [%s] %s\n", sname,  line, command, msg);
-    } else {
-        snprintf(tmp, strlen(sname) + 128 + strlen(msg), "%s %d: %s\n", sname,  line, msg);
-    }
+    snprintf(tmp, strlen(sname) + 128 + strlen(msg), "%s %d: %s\n", sname,  line, msg);
 
     string_put(gErrMsg, tmp);
     FREE(tmp);
 }
 
-void err_msg_adding(char* msg, char* sname, int line, char* command)
+void err_msg_adding(char* msg, char* sname, int line)
 {
     char* tmp = MALLOC(strlen(sname) + 128 + strlen(msg));
-    snprintf(tmp, strlen(sname) + 128 + strlen(msg), "%s %d: [%s] %s\n", sname,  line, command, msg);
+    snprintf(tmp, strlen(sname) + 128 + strlen(msg), "%s %d: %s\n", sname,  line, msg);
 
     string_push_back(gErrMsg, tmp);
     FREE(tmp);
